## Project Description

Azure-Transcribe is a service that transcribes speech from audio files to text using Microsoft Azure Cognitive Services.

## Requirements

* Python (3.6 or higher)
* azure-storage-blob

## Installation
Install using pip

`pip install azure-transcribe`

## P.S.

If you find bugs, need help, or want to talk to the developers, please write an issue on [GitHub](https://github.com/DCDie/azure-transcribe/issues).
